#Plot_Macrophyte_Density_and_Composition
#Meredith Brehob
#5/9/2022
#This code will plot macrophyte density and composition for each sampling event.

#Load Packages
library(ggplot2)
library(cowplot)

##### Read in Data #####
canal_aves <- read.csv("Data_Final/Macrophyte_Density_SiteAverages.csv")
canal_sp_aves <- read.csv("Data_Final/Macrophyte_Composition_SiteAverages.csv")


##### Macrophyte Density Plot #####
fill.order <- factor(canal_aves$Canal, levels = c('UL', 'DL', 'A'))#creating fill order so that it is in correct sampling order
g1<-
  ggplot(canal_aves, aes(x = Canal, y = mean_Biomass_per_Area, fill = fill.order)) + 
  geom_bar(stat = 'identity') + facet_grid(~ Event)+
  labs(y=expression(paste("Biomass per area (g/", m^2,")")))+
  theme_bw()+
  theme(legend.position = "none",
        panel.grid.minor = element_blank(),
        panel.grid.major.x = element_blank(),
        axis.title.x=element_blank(),
        axis.text = element_text(size=10),
        plot.title=element_text(size=11, hjust=0.5))+#specify theme elements. Get rid of x axis title because bottom graph already has it. Edit "title" (really just Event label) attributes here
  scale_fill_manual(values = c("UL" = "#FA492D", "DL" = "#5F98FA", "A" = "#85AD1F"))+ #add colors that I want
  geom_errorbar(aes(ymin=mean_Biomass_per_Area-sd_Biomass_per_Area, ymax=mean_Biomass_per_Area+sd_Biomass_per_Area), width=.2,position=position_dodge(.9),stat="identity")+#add error bars
    geom_label(aes(label=Date), fill="white", color="black", vjust=-5,size=3.2,label.size = 0, label.padding=unit(0.01, "lines"))+#add labels (label.size specifies line width (none), while label.padding makes padding around text appropriately sized)
  ggtitle("Event")#Want to have label for event so added it as a "title"
  

##### Proportion of Macrophyte Composition Plot #####
g2<-
  ggplot(canal_sp_aves, aes(x = Canal, y = Biomass_per_Area, fill = Plant_Type)) + 
  geom_bar(stat = 'identity', position = 'fill') + facet_grid(~ Event)+
  labs(y=expression(paste("Biomass per area - proportion")),fill="Plant Type") +
  theme_bw()+
  theme(panel.grid.major.x = element_blank(),
        panel.grid.minor = element_blank(),
        axis.text = element_text(size=10),
        legend.position = "bottom",
        legend.text = element_text(size=10),
        legend.title=element_text(size=10),
        legend.direction = "horizontal")+
  scale_fill_manual(values=c("#A34B03", "#2B3715", "#FEC10D", "#E6860A","#75954F","#786F65"))


##### Combine Plots #####
g2noleg <- g2 + theme(legend.position = "none")#Make graph 2 without it's legend
le1 <- get_legend(g2)#Create an object of the legend from graph 2
graph1<-plot_grid(g1, g2noleg, ncol=1, align="v", rel_heights = c(3,2), labels="AUTO", scale=0.95)#Plot just the two graphs (no legend) so that I can align the y axes
plot_grid(graph1, le1, nrow = 2, rel_heights = c(1,0.15))#Then add the legend onto the two graphs from last line

